@@ -6,15 +6,15 @@
 
 #include <QDebug>
 
-#include <pappsomspp/utils.h>
-#include <pappsomspp/trace/datapoint.h>
-#include <pappsomspp/trace/trace.h>
-#include <pappsomspp/trace/maptrace.h>
-#include <pappsomspp/massspectrum/massspectrum.h>
-#include <pappsomspp/processing/combiners/massdatacombinerinterface.h>
-#include <pappsomspp/processing/combiners/massspectrumpluscombiner.h>
+#include <pappsomspp/core/utils.h>
+#include <pappsomspp/core/trace/datapoint.h>
+#include <pappsomspp/core/trace/trace.h>
+#include <pappsomspp/core/trace/maptrace.h>
+#include <pappsomspp/core/massspectrum/massspectrum.h>
+#include <pappsomspp/core/processing/combiners/massdatacombinerinterface.h>
+#include <pappsomspp/core/processing/combiners/massspectrumpluscombiner.h>
 
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 namespace pappso
 {
@@ -149,10 +149,10 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
 
     MzIntegrationParams mz_integration_params(610.02,
                                               611.97,
-                                              BinningType::ARBITRARY,
-                                              decimal_places,
+                                              MzIntegrationParams::BinningType::ARBITRARY,
                                               precision_p,
                                               binSizeDivisor,
+                                              decimal_places,
                                               true);
 
     // Check that it does not compute bins, since BinningType::NONE.
@@ -275,10 +275,10 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
 
     MzIntegrationParams mz_integration_params(610.02,
                                               610.975,
-                                              BinningType::ARBITRARY,
-                                              decimal_places,
+                                              MzIntegrationParams::BinningType::ARBITRARY,
                                               precision_p,
                                               binSizeDivisor,
+                                              decimal_places,
                                               true);
 
     // Check that it does not compute bins, since BinningType::NONE.
