@@ -28,9 +28,9 @@
 #include <catch2/catch_approx.hpp>
 
 #include <iostream>
-#include <pappsomspp/peptide/peptidenaturalisotopeaverage.h>
-#include <pappsomspp/peptide/peptidenaturalisotopelist.h>
-#include <pappsomspp/peptide/peptidestrparser.h>
+#include <pappsomspp/core/peptide/peptidenaturalisotopeaverage.h>
+#include <pappsomspp/core/peptide/peptidenaturalisotopelist.h>
+#include <pappsomspp/core/peptide/peptidestrparser.h>
 // #include "common.h"
 #include "config.h"
 
