@@ -35,11 +35,11 @@
 #include <catch2/matchers/catch_matchers_vector.hpp>
 
 
-#include <pappsomspp/pappsoexception.h>
-#include <pappsomspp/mzrange.h>
-#include <pappsomspp/peptide/peptidefragment.h>
+#include <pappsomspp/core/pappsoexception.h>
+#include <pappsomspp/core/mzrange.h>
+#include <pappsomspp/core/peptide/peptidefragment.h>
 
-#include <pappsomspp/peptide/peptidefragmention.h>
+#include <pappsomspp/core/peptide/peptidefragmention.h>
 #include <iostream>
 #include <QDebug>
 #include <QString>
@@ -73,13 +73,13 @@ TEST_CASE("Peptide Fragment test suite.", "[peptidefragment]")
     REQUIRE_NOTHROW(PeptideFragmentIon(
       std::make_shared<PeptideFragment>(
         std::make_shared<Peptide>("PEPTIDE"), PeptideDirection::Nter, 4),
-      PeptideIon::a));
+      Enums::PeptideIon::a));
 
     REQUIRE_THROWS_AS(
       PeptideFragmentIon(
         std::make_shared<PeptideFragment>(
           std::make_shared<Peptide>("PEPTIDE"), PeptideDirection::Nter, 4),
-        PeptideIon::y),
+        Enums::PeptideIon::y),
       pappso::PappsoException);
   }
 }
